# EduceLab Image Processing

`educelab-imgproc` is a Python module for performing common image
processing tasks. This module is largely a collection of wrapper functions
around functionality provided by other toolkits (numpy, scikit-image, etc.) and
is meant to encourage consistent, predictable use across EduceLab projects.
It should not be considered a total replacement for those other, wonderful
toolkits.

## Requirements
- Python 3.9+

## Installation

This project is available on PyPI:

```shell
python3 -m pip install educelab-imgproc
```

## API Documentation

Visit our API documentation [here](https://educelab.gitlab.io/educelab-imgproc/).